@@ -2,13 +2,13 @@ from typing import Optional, List
 
 from camel_model.camel_model import CamelModel
 
-from domain.power_supply.power_supply_component import PowerSupplyComponent
-from domain.electronic.electronic_element import ElectronicElement
+from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
+from xlsx_lib.domain.electronic.electronic_element import ElectronicElement
 
-from domain.engine.engine_section import EngineSection
-from domain.frame.frame_element import FrameElement
-from domain.generic_replacements.replacement import Replacement
-from domain.tightening_specifications.specification_element import SpecificationElement
+from xlsx_lib.domain.engine.engine_section import EngineSection
+from xlsx_lib.domain.frame.frame_element import FrameElement
+from xlsx_lib.domain.generic_replacements.replacement import Replacement
+from xlsx_lib.domain.tightening_specifications.specification_element import SpecificationElement
 
 
 class MotorcycleModel(CamelModel):
