@@ -5,8 +5,8 @@ from openpyxl import \
     Workbook, \
     load_workbook
 
-from domain.power_supply.power_supply_component import PowerSupplyComponent
-from domain.power_supply.power_supply_sheet import PowerSupplySheet
+from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
+from xlsx_lib.domain.power_supply.power_supply_sheet import PowerSupplySheet
 from xlsx_lib.domain.frame.frame_element import FrameElement
 from xlsx_lib.domain.frame.frame_sheet import FrameSheet
 from xlsx_lib.domain.motorcycle_model.motorcycle_model import MotorcycleModel
